@@ -11,9 +11,10 @@ logging.basicConfig(
 logger = logging.getLogger(__name__)
 
 from .interface import Lister, Getter, Creator, Updater, Deleter, S3, Utils
+from .gen import MessageGenerator
 
 
-class LogQS:
+class LogQSClient:
     def __init__(
         self,
         api_url=None,
@@ -80,3 +81,7 @@ class LogQS:
 
         self.s3 = S3(creator=self.create)
         self.utils = Utils(s3=self.s3, config=self.config)
+        self.gen = MessageGenerator(getter=self.get, lister=self.list)
+
+
+LogQS = LogQSClient
